# Instabuy python 3 integration package #

What this package can do:

- Self update integration robots
- Send exceptions logs to Instabuy
- Download buys
- Upload products
- Local products cache
- Parse robots config

It contains:
- Instabuy commons order and products models
- Commons data parsers

Python versions supported >= 3.7.7
